@@ -204,6 +204,10 @@ def create_text_box(
     disabled_background_color = "#2d2d2d",
     disabled_border_width = 2,
     disabled_border_color = "#4a4a4a",
+    show_text_icon_url = str(icons_dir / "show_text_icon.png"),
+    hide_text_icon_url = str(icons_dir / "hide_text_icon.png"),
+    focused_show_text_icon_url = str(icons_dir / "focused_show_text_icon.png"),
+    focused_hide_text_icon_url = str(icons_dir / "focused_hide_text_icon.png"),
     hide_text = False
 ):
     text_box = QLineEdit()
@@ -235,10 +239,10 @@ def create_text_box(
     """
     text_box.setStyleSheet(style_sheet)
     if hide_text:
-        show_text_icon = QIcon(str(icons_dir / "show_text_icon.png"))
-        hide_text_icon = QIcon(str(icons_dir / "hide_text_icon.png"))
-        focused_show_text_icon = QIcon(str(icons_dir / "focused_show_text_icon.png"))
-        focused_hide_text_icon = QIcon(str(icons_dir / "focused_hide_text_icon.png"))
+        show_text_icon = QIcon(show_text_icon_url)
+        hide_text_icon = QIcon(hide_text_icon_url)
+        focused_show_text_icon = QIcon(focused_show_text_icon_url)
+        focused_hide_text_icon = QIcon(focused_hide_text_icon_url)
         text_box.setEchoMode(QLineEdit.EchoMode.Password)
         toggle_text_visibility_button = QToolButton(text_box)
         toggle_text_visibility_button.setCursor(Qt.CursorShape.PointingHandCursor)
@@ -360,21 +364,25 @@ def create_checkbox(
     font_color = "#ffffff",
     background_color = "#1e1e1e",
     padding = 15,
-    border_width = 2,
-    border_color = "#5c5c5c",
-    border_radius = 0,
-    hover_background_color = "#333333",
-    hover_border_width = 3,
-    hover_border_color = "#777777",
-    pressed_background_color = "#4a4a4a",
-    pressed_border_width = 3,
-    pressed_border_color = "#0078d7",
+    indicator_background_color = "#1e1e1e",
+    indicator_border_width = 1,
+    indicator_border_color = "#5c5c5c",
+    indicator_border_radius = 100,
+    hover_indicator_background_color = "#333333",
+    hover_indicator_border_width = 2,
+    hover_indicator_border_color = "#777777",
+    pressed_indicator_background_color = "#4a4a4a",
+    pressed_indicator_border_width = 2,
+    pressed_indicator_border_color = "#0078d7",
+    checked_indicator_background_color = "#0078d7",
+    checked_indicator_border_width = 2,
+    checked_indicator_border_color = "#ffffff",
     disabled_font_color = "#888888",
     disabled_background_color = "#2d2d2d",
-    disabled_border_width = 2,
+    disabled_border_width = 1,
     disabled_border_color = "#4a4a4a"
 ):
-    checkbox = QCheckBox(text)
+    check_box = QCheckBox(text)
     style_sheet = f"""
         QCheckBox {{
             font-family: {font_family};
@@ -382,25 +390,32 @@ def create_checkbox(
             color: {font_color};
             background-color: {background_color};
             padding: {padding}px;
-            border: {border_width}px solid {border_color};
-            border-radius: {border_radius}px;
         }}
-        QCheckBox:hover {{
-            background-color: {hover_background_color};
-            border: {hover_border_width}px solid {hover_border_color};
+        QCheckBox::indicator {{
+            background-color: {indicator_background_color};
+            border: {indicator_border_width}px solid {indicator_border_color};
+            border-radius: {indicator_border_radius}px;
         }}
-        QCheckBox:pressed {{
-            background-color: {pressed_background_color};
-            border: {pressed_border_width}px solid {pressed_border_color};
+        QCheckBox::indicator:hover {{
+            background-color: {hover_indicator_background_color};
+            border: {hover_indicator_border_width}px solid {hover_indicator_border_color};
         }}
-        QCheckBox:disabled {{
+        QCheckBox::indicator:pressed {{
+            background-color: {pressed_indicator_background_color};
+            border: {pressed_indicator_border_width}px solid {pressed_indicator_border_color};
+        }}
+        QCheckBox::indicator:checked {{
+            background-color: {checked_indicator_background_color};
+            border: {checked_indicator_border_width}px solid {checked_indicator_border_color};
+        }}
+        QCheckBox::indicator:disabled {{
             color: {disabled_font_color};
             background-color: {disabled_background_color};
             border: {disabled_border_width}px solid {disabled_border_color};
         }}
     """
-    checkbox.setStyleSheet(style_sheet)
-    return checkbox
+    check_box.setStyleSheet(style_sheet)
+    return check_box
 
 def create_information_message_box(
     text,
